var m=Object.defineProperty;var i=(o,t)=>m(o,"name",{value:t,configurable:!0});import{openBlock as p,createElementBlock as e,createElementVNode as r,toDisplayString as s}from"vue";import{d as l}from"./index-IEXYnpa0.js";import"@primevue/themes";import"@primevue/themes/aura";import"./vendor-other-Co5CJDU0.js";import"./vendor-vue-BQi1bXU_.js";import"primevue/config";import"primevue/confirmationservice";import"primevue/toastservice";import"primevue/tooltip";import"primevue/button";import"vue-i18n";import"primevue/message";import"primevue/skeleton";import"primevue/multiselect";import"primevue/inputtext";import"primevue/select";import"primevue/iconfield";import"primevue/inputicon";import"primevue/checkbox";import"primevue/divider";import"primevue/scrollpanel";import"primevue/usetoast";import"primevue/card";import"primevue/listbox";import"primevue/progressbar";import"primevue/floatlabel";import"@primevue/forms";import"@primevue/forms/resolvers/zod";import"primevue/password";import"primevue/progressspinner";import"primevue/tag";import"primevue/inputnumber";import"primevue/tabpanels";import"primevue/tabs";import"primevue/badge";import"primevue/chip";import"primevue/tabpanel";import"primevue/toggleswitch";import"primevue/colorpicker";import"primevue/radiobutton";import"primevue/knob";import"primevue/slider";import"primevue/panel";import"primevue/tabmenu";import"primevue/popover";import"primevue/tab";import"primevue/tablist";import"primevue";import"./vendor-xterm-DV1MVhAx.js";import"./vendor-three-zdhtZbSm.js";import"primevue/galleria";import"primevue/contextmenu";import"primevue/tree";import"primevue/toolbar";import"primevue/selectbutton";import"primevue/dialog";import"primevue/confirmdialog";import"primevue/autocomplete";import"primevue/dropdown";import"./vendor-tiptap-CihWyaWo.js";import"primevue/blockui";const a={},d={class:"relative size-full overflow-hidden rounded"},n={class:"flex size-full flex-col items-center justify-center gap-2 bg-modal-card-placeholder-background transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105"},c={class:"text-sm text-base-foreground"};function u(o,t){return p(),e("div",d,[r("div",n,[t[0]||(t[0]=r("i",{class:"icon-[lucide--box] text-3xl text-muted-foreground"},null,-1)),r("span",c,s(o.$t("assetBrowser.media.threeDModelPlaceholder")),1)])])}i(u,"_sfc_render");const Dt=l(a,[["render",u]]);export{Dt as default};
//# sourceMappingURL=Media3DTop-CGwAMt8Z.js.map
