import{defineComponent as f,mergeModels as p,useModel as h,computed as t,openBlock as g,createElementBlock as v,createVNode as d,createElementVNode as w}from"vue";import{v as l}from"./index-IEXYnpa0.js";import{i as y}from"./nodeFilterUtil-D49mCu4H.js";import{a as V}from"./audioUtils-BFYJkwJ-.js";import{_}from"./WidgetSelect.vue_vue_type_script_setup_true_lang-Btko4ViS.js";import N from"./AudioPreviewPlayer-B5uLZLnK.js";import"@primevue/themes";import"@primevue/themes/aura";import"./vendor-other-Co5CJDU0.js";import"./vendor-vue-BQi1bXU_.js";import"primevue/config";import"primevue/confirmationservice";import"primevue/toastservice";import"primevue/tooltip";import"primevue/button";import"vue-i18n";import"primevue/message";import"primevue/skeleton";import"primevue/multiselect";import"primevue/inputtext";import"primevue/select";import"primevue/iconfield";import"primevue/inputicon";import"primevue/checkbox";import"primevue/divider";import"primevue/scrollpanel";import"primevue/usetoast";import"primevue/card";import"primevue/listbox";import"primevue/progressbar";import"primevue/floatlabel";import"@primevue/forms";import"@primevue/forms/resolvers/zod";import"primevue/password";import"primevue/progressspinner";import"primevue/tag";import"primevue/inputnumber";import"primevue/tabpanels";import"primevue/tabs";import"primevue/badge";import"primevue/chip";import"primevue/tabpanel";import"primevue/toggleswitch";import"primevue/colorpicker";import"primevue/radiobutton";import"primevue/knob";import"primevue/slider";import"primevue/panel";import"primevue/tabmenu";import"primevue/popover";import"primevue/tab";import"primevue/tablist";import"primevue";import"./vendor-xterm-DV1MVhAx.js";import"./vendor-three-zdhtZbSm.js";import"primevue/galleria";import"primevue/contextmenu";import"primevue/tree";import"primevue/toolbar";import"primevue/selectbutton";import"primevue/dialog";import"primevue/confirmdialog";import"primevue/autocomplete";import"primevue/dropdown";import"./vendor-tiptap-CihWyaWo.js";import"primevue/blockui";import"./widgetPropFilter-CygYoMQt.js";import"./index-UhZrqPKB.js";import"./WidgetLayoutField.vue_vue_type_script_setup_true_lang-277zi_kd.js";import"./LazyImage.vue_vue_type_script_setup_true_lang-BEjdi0-r.js";import"primevue/tieredmenu";const I={class:"w-full"},B={class:"my-4"},Do=f({__name:"WidgetAudioUI",props:p({widget:{},readonly:{type:Boolean},nodeId:{}},{modelValue:{},modelModifiers:{}}),emits:p(["update:modelValue"],["update:modelValue"]),setup(i){const r=i,e=h(i,"modelValue"),a=t(()=>!r.nodeId||!l.rootGraph?null:l.rootGraph.getNodeById(r.nodeId)),u=t(()=>{const o=a.value;return o?y(o):!1}),n=t(()=>r.widget.value),s=t(()=>{const o=n.value;return o?V(o,"input"):""});return(o,m)=>(g(),v("div",I,[d(_,{modelValue:e.value,"onUpdate:modelValue":m[0]||(m[0]=c=>e.value=c),widget:o.widget},null,8,["modelValue","widget"]),w("div",B,[d(N,{"audio-url":s.value,readonly:o.readonly,"hide-when-empty":u.value,"show-options-button":!0},null,8,["audio-url","readonly","hide-when-empty"])])]))}});export{Do as default};
//# sourceMappingURL=WidgetAudioUI-CtjXbu9b.js.map
